@@ -6,8 +6,7 @@ from typing import List
 
 import requests
 
-LOGGER = logging.getLogger("corganizeclient")
-logging.basicConfig()
+LOGGER = logging.getLogger(__name__)
 
 
 @dataclass(frozen=True)
@@ -22,6 +21,14 @@ class CorganizeClient:
     def _compose_url(self, resource):
         return "/".join([s.strip("/") for s in (self.host, resource)])
 
+    def get_file(self, fileid) -> dict:
+        url = self._compose_url(f"/files/{fileid}")
+        r = requests.get(url, headers=self._default_headers)
+        if r.status_code == 404:
+            return None
+        r.raise_for_status()
+        return r.json()
+
     def get_recently_modified_files(self, **kwargs):
         url = self._compose_url("/files")
         return self._get_paginated_files(url, **kwargs)
@@ -48,34 +55,16 @@ class CorganizeClient:
         url = self._compose_url("/files/incomplete")
         return self._get_paginated_files(url, **kwargs)
 
-    def create_files(self, files: List[dict], chunk_size: int = 50, interval: int = 15):
-        url = self._compose_url("/files")
-        remaining_files = files
-        result = dict(
-            created=[],
-            skipped=[],
-            failed=[]
-        )
+    def create_files(self, files: List[dict]):
+        assert isinstance(files, list)
 
-        while True:
-            chunk = remaining_files[:chunk_size]
-            r = requests.post(url, json=chunk, headers=self._default_headers)
+        url = self._compose_url("/files/bulk")
+        r = requests.post(url, json=files, headers=self._default_headers)
 
-            if not r.ok:
-                result["failed"] += [f["fileid"] for f in chunk]
+        if not r.ok:
+            raise RuntimeError(r.text)
 
-            chunk_result = r.json()
-            result["created"] += chunk_result["created"]
-            result["skipped"] += chunk_result["skipped"]
-
-            remaining_files = remaining_files[chunk_size:]
-            if len(remaining_files) == 0:
-                break
-
-            LOGGER.debug(f"Sleeping for {interval=} seconds; {len(remaining_files)=}")
-            sleep(interval)
-
-        return result
+        return r.json()
 
     def update_file(self, file):
         assert isinstance(file, dict)
